/*
 *  PoolMan Java Object Pooling and Caching Library
 *  Copyright (C) 1999-2001 The Code Studio
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  The full license is located at the root of this distribution
 *  in the LICENSE file.
 */
package com.codestudio;

public interface PoolManConstants {

    /* RELEASE CONSTANTS */
    public static final String RELEASE_NAME = "PoolMan Resource Management Library";
    public static final String RELEASE_MAJOR_VERSION = "2";
    public static final String RELEASE_MINOR_VERSION = "1";
    public static final String RELEASE_FULL_NAME = RELEASE_NAME + " v" + RELEASE_MAJOR_VERSION +
            "." + RELEASE_MINOR_VERSION;

    /* DEFAULT CONFIG VALUES */
    public static final String XML_CONFIG_FILE = "poolman.xml";
    public static final String PROPS_CONFIG_FILE = "poolman.props";
    public static final String OLDPROPS_CONFIG_FILE = "pool.props";
    public static final String DATASOURCE_SVC_CLASSNAME = "com.codestudio.management.DataSourceService";
    public static final String GENERIC_SVC_CLASSNAME = "com.codestudio.management.GenericPoolService";

    /* Whether or not to use JMX for configuration and management of all pools. */
    public static final boolean DEFAULT_USE_JMX = false;


    /* DEFAULT OBJECT POOL VALUES */
    public static final int DEFAULT_INITIAL_SIZE = 1;             // 1 object
    public static final int DEFAULT_TIMEOUT = 1200;               // 20 minutes
    public static final int DEFAULT_SKIMMER_SLEEP = 420;	      // 7 minutes
    public static final int DEFAULT_MAX_SIZE = Integer.MAX_VALUE; // System's max
    public static final int DEFAULT_MIN_SIZE = 0;                 // shrinks to 0
    public static final int DEFAULT_USERTIMEOUT = 20;	          // 20 seconds
    public static final int DEFAULT_SHRINKBY = 5;                 // Shrink 5 objects per GC cycle

    public static final int DEFAULT_ISO_LEVEL = java.sql.Connection.TRANSACTION_READ_COMMITTED;

    /* Create objects even if the max has been reached if there are no more
     * available in the pool. Let the GC PoolSkimmer automatically shrink
     * the pool back to acceptable size later.
     */
    public static final boolean DEFAULT_EMERGENCY_CREATES = true;

    /* DEFAULT JDBC POOL VALUES */
    public static final boolean DEFAULT_POOL_PREP_STATEMENTS= true;  // pool prepared statements by default
    public static final boolean DEFAULT_REMOVE_ON_EXC = false;       // exceptions don't kill cons
    public static final boolean DEFAULT_CACHE_ENABLED = false;       // no caching by default
    public static final int DEFAULT_CACHE_SIZE = 5;                  // 5 objects
    public static final int DEFAULT_CACHE_REFRESH = 30;              // 30 seconds

}
