package com.codestudio.management;

import java.net.URL;
import java.net.URLClassLoader;


/**
 * Encountered Class linkage problems in somce ClassLoaders --
 * such as the one used with the Swing and AWT views of JUnit (JUnit's
 * text-based view was fine, since it doesn't use the same CL) and
 * some versions of Tomcat -- that are compounded by extraneous
 * loader context switching in the JMX RI. This ClassLoader does
 * nothing other than insist that MBeans are loaded by a specific
 * loader in order to avoid linkage problems between contexts.
 */
public class JMXClassLoader extends URLClassLoader implements JMXClassLoaderMBean {

    private ClassLoader parent;

    public JMXClassLoader(ClassLoader parent) {
        super(new URL[0], parent);
        this.parent = parent;
    }

    public Class loadClass(String name) throws ClassNotFoundException {
        return parent.loadClass(name);
    }

}
