/*
 *  PoolMan Java Object Pooling and Caching Library
 *  Copyright (C) 1999-2001 The Code Studio
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  The full license is located at the root of this distribution
 *  in the LICENSE file.
 */
package com.codestudio.util;

import java.io.Serializable;

/**
 * An object aware of its pool, lifespan, and possibly other resources.
 */
public interface PooledObject extends Serializable {

    /** Remove an object's caller state */
    public void clean();

    /**
     * Retrieve the pool containing this Object.
     * @return ObjectPool The pool that contains this object
     */
    public ObjectPool getPool();

    /** Disassociate resource references from this object */
    public void closeAllResources();

}

